pub struct RegisterHistory(/* private fields */);Implementations
Sourceimpl RegisterHistory
impl RegisterHistory
pub fn into_reference( val: RegisterHistory, env: Env, ) -> Result<Reference<RegisterHistory>>
pub fn into_instance(self, env: Env) -> Result<ClassInstance<RegisterHistory>>
Sourceimpl RegisterHistory
impl RegisterHistory
pub fn new() -> Self
Sourcepub async fn next(&self) -> Result<Option<Uint8Array>>
pub async fn next(&self) -> Result<Option<Uint8Array>>
Fetch and go to the next register value from the history.
Returns null when we reached the end.
Sourcepub async fn collect(&self) -> Result<Vec<Uint8Array>>
pub async fn collect(&self) -> Result<Vec<Uint8Array>>
Get all the register values from the history, starting from the first to the latest entry